======================================================
 :mod:`xoeuf.api` -- Extensions for Odoo's api module
======================================================

.. versionadded:: 0.5.0

.. automodule:: xoeuf.api

This module imports from Odoo's own ``api``, you can use it as a replacement.


.. autofunction:: contextual

.. autofunction:: requires_singleton

.. autofunction:: mimic

.. autofunction:: from_active_ids(f, leak_context=False)

.. autofunction:: onupdate
